@@ -1,7 +1,7 @@
 package Data::Unixish::Apply;
 
-our $DATE = '2014-12-10'; # DATE
-our $VERSION = '1.48'; # VERSION
+our $DATE = '2015-01-03'; # DATE
+our $VERSION = '1.49'; # VERSION
 
 use 5.010;
 use strict;
@@ -104,7 +104,7 @@ sub apply {
 }
 
 1;
-# ABSTRACT: Apply one or more dux functions to data
+# ABSTRACT: Apply one or more dux functions
 
 __END__
 
@@ -114,11 +114,11 @@ __END__
 
 =head1 NAME
 
-Data::Unixish::Apply - Apply one or more dux functions to data
+Data::Unixish::Apply - Apply one or more dux functions
 
 =head1 VERSION
 
-This document describes version 1.48 of Data::Unixish::Apply (from Perl distribution Data-Unixish), released on 2014-12-10.
+This document describes version 1.49 of Data::Unixish::Apply (from Perl distribution Data-Unixish), released on 2015-01-03.
 
 =head1 SYNOPSIS
 
@@ -141,7 +141,7 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<functions>* => I<array|str>
+=item * B<functions>* => I<str|array[str|array]>
 
 Function(s) to apply.
 
@@ -161,8 +161,6 @@ Example:
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -172,15 +170,14 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
-
+Return value:  (any)
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixish>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Data-Unixish>.
+Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish>.
 
 =head1 BUGS
 
@@ -196,7 +193,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
