@@ -10,7 +10,7 @@ use warnings;
 require Data::Unixish; # for siduxs
 use Data::Unixish::Util qw(%common_args);
 
-our $VERSION = '1.48'; # VERSION
+our $VERSION = '1.49'; # VERSION
 
 our %SPEC;
 
@@ -105,7 +105,7 @@ Data::Unixish::cond - Apply dux function conditionally
 
 =head1 VERSION
 
-This document describes version 1.48 of Data::Unixish::cond (from Perl distribution Data-Unixish), released on 2014-12-10.
+This document describes version 1.49 of Data::Unixish::cond (from Perl distribution Data-Unixish), released on 2015-01-03.
 
 =head1 SYNOPSIS
 
@@ -140,11 +140,11 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<else> => I<array|str>
+=item * B<else> => I<str|array>
 
 dux function to be applied if condition is false.
 
-=item * B<if>* => I<code|str>
+=item * B<if>* => I<str|code>
 
 Perl code that specifies the condition.
 
@@ -156,14 +156,12 @@ Input stream (e.g. array or filehandle).
 
 Output stream (e.g. array or filehandle).
 
-=item * B<then>* => I<array|str>
+=item * B<then>* => I<str|array>
 
 dux function to be applied if condition is true.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -173,15 +171,14 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
-
+Return value:  (any)
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixish>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Data-Unixish>.
+Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish>.
 
 =head1 BUGS
 
@@ -197,7 +194,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
