@@ -8,7 +8,7 @@ use warnings;
 
 use Data::Unixish::Util qw(%common_args);
 
-our $VERSION = '1.48'; # VERSION
+our $VERSION = '1.49'; # VERSION
 
 our %SPEC;
 
@@ -63,7 +63,7 @@ sub _indent_item {
 }
 
 1;
-# ABSTRACT: Add spaces or tabs to the beginning of each line of text
+# ABSTRACT: Add spaces or tabs to the beginnning of each line of text
 
 __END__
 
@@ -73,11 +73,11 @@ __END__
 
 =head1 NAME
 
-Data::Unixish::indent - Add spaces or tabs to the beginning of each line of text
+Data::Unixish::indent - Add spaces or tabs to the beginnning of each line of text
 
 =head1 VERSION
 
-This document describes version 1.48 of Data::Unixish::indent (from Perl distribution Data-Unixish), released on 2014-12-10.
+This document describes version 1.49 of Data::Unixish::indent (from Perl distribution Data-Unixish), released on 2015-01-03.
 
 =head1 SYNOPSIS
 
@@ -122,8 +122,6 @@ Number of spaces to add.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -133,8 +131,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
-
+Return value:  (any)
 =head1 SEE ALSO
 
 lins, rins
@@ -145,7 +142,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixi
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Data-Unixish>.
+Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish>.
 
 =head1 BUGS
 
@@ -161,7 +158,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
