@@ -10,7 +10,7 @@ use warnings;
 use Data::Unixish::_pad;
 use Data::Unixish::Util qw(%common_args);
 
-our $VERSION = '1.48'; # VERSION
+our $VERSION = '1.49'; # VERSION
 
 our %SPEC;
 
@@ -82,7 +82,7 @@ Data::Unixish::rpad - Pad text to the right until a certain column width
 
 =head1 VERSION
 
-This document describes version 1.48 of Data::Unixish::rpad (from Perl distribution Data-Unixish), released on 2014-12-10.
+This document describes version 1.49 of Data::Unixish::rpad (from Perl distribution Data-Unixish), released on 2015-01-03.
 
 =head1 SYNOPSIS
 
@@ -145,8 +145,6 @@ Whether to truncate text wider than specified width.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -156,15 +154,14 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
- (any)
-
+Return value:  (any)
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixish>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Data-Unixish>.
+Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish>.
 
 =head1 BUGS
 
@@ -180,7 +177,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
